flutter_custom_lints library
A collection of custom lint rules for Flutter and Dart projects.
This library provides lint rules that enforce best practices and prevent common coding mistakes, including:
DisposeControllers: Ensures controllers are properly disposedNoAsTypeAssertion: Prevents unsafe type casting withasNoDirectIterableAccess: Prevents unsafe collection accessNoNullForce: Prevents force unwrapping of nullable valuesUseCompareWithoutCase: Suggests efficient string comparison
Functions
-
createPlugin(
) → PluginBase